@@ -4,7 +4,7 @@ from thousandwords.auth import CognitoAuth
 
 class CognitoCredentials:
   def __init__(self):
-    self._cognito = boto3.client('cognito-identity')
+    self._cognito = boto3.Session(region_name=CONFIG.cognito_region).client('cognito-identity')
     self._credentials = None
   
   @property
